@@ -536,43 +536,43 @@ def copy_dir(src, dst, symlinks=False, ignore=None, ignore_file=None):
         s = os.path.join(src, item)
         d = os.path.join(dst, item)
 
-        if os.path.isdir(s):
-            copy_dir(s, d, symlinks, ignore, ignore_file)
-        else:
-            can_copy = True
+        can_copy = True
 
-            if os.path.islink(s):
-                if symlinks:
-                    if ignore_file is None:
-                        ignored_file = False
-                    else:
-                        ignored_file = ignore_file(s)
-
-                    if not ignored_file:
-                        if os.path.lexists(d):
-                            os.remove(d)
-
-                        os.symlink(os.readlink(s), d)
-
-                        if hasattr(os, "lchmod"):
-                            st = os.lstat(s)
-                            mode = stat.S_IMODE(st.st_mode)
-                            os.lchmod(d, mode)
-                else:
-                    # ignore this symlink
-                    can_copy = False
-
-            if can_copy:
+        if os.path.islink(s):
+            if symlinks:
                 if ignore_file is None:
                     ignored_file = False
                 else:
                     ignored_file = ignore_file(s)
 
                 if not ignored_file:
-                    try:
-                        shutil.copy2(s, d)
-                    except IOError:
-                        pass
+                    if os.path.lexists(d):
+                        os.remove(d)
+
+                    os.symlink(os.readlink(s), d)
+
+                    if hasattr(os, "lchmod"):
+                        st = os.lstat(s)
+                        mode = stat.S_IMODE(st.st_mode)
+                        os.lchmod(d, mode)
+            else:
+                # ignore this symlink
+                can_copy = False
+        elif os.path.isdir(s):
+            copy_dir(s, d, symlinks, ignore, ignore_file)
+            can_copy = False
+
+        if can_copy:
+            if ignore_file is None:
+                ignored_file = False
+            else:
+                ignored_file = ignore_file(s)
+
+            if not ignored_file:
+                try:
+                    shutil.copy2(s, d)
+                except IOError:
+                    pass
 
 
 # -----------------------------------------------------------------------------
